# symbolic-dynamics

A symbolic dynamics package for Python using NetworkX

[![Documentation Status](https://readthedocs.org/projects/symbolic-dynamics/badge/?version=latest)](https://symbolic-dynamics.readthedocs.io/en/latest/?badge=latest)

Documentation: https://symbolic-dynamics.readthedocs.io/en/latest/